@@ -23,7 +23,8 @@ def _oidc_login(
     code_challenge_method: str = "S256",
     code_verifier: str = "kFn5ZwL6ggOwU1OzKx0E1oZibIMC1ZbMC1WEUXcCV5mFoi015I9nB9CrgUJRkc3oiQT8uBbrvRvVzahM8OS0xJ51XdYaTdAlFeHsb6OZuBPmLD400ozVPrwCE192rtqI",
     callback_port: int = 28282,
-    delay_seconds: int = 300,
+    delay_seconds: int = 60,
+    gui=None,
 ):
     """
     Primary OIDC login flow.
@@ -32,6 +33,7 @@ def _oidc_login(
     djsciops_utils.log(
         "User authentication required to use DataJoint SciOps CLI tools. We'll be launching a web browser to authenticate your DataJoint account.",
         pause_duration=5,
+        gui=gui,
     )
     # allocate variables for access and context
     code = None
@@ -114,14 +116,14 @@ def _oidc_login(
         browser_available = False
     if browser_available:
         djsciops_utils.log(
-            f"Browser available. Launching...",
-            pause_duration=1,
+            f"Browser available. Launching...", pause_duration=1, gui=gui
         )
         webbrowser.open(link, new=2)
     else:
         djsciops_utils.log(
             f"Brower unavailable. On a browser client, please navigate to the following link to login: {link}\n",
             pause_duration=1,
+            gui=gui,
         )
     # start response server
     cancel_process = multiprocessing.Process(
@@ -140,7 +142,7 @@ def _oidc_login(
             "User login cancelled. User must be logged in to use DataJoint SciOps CLI tools."
         )
     else:
-        djsciops_utils.log("User successfully authenticated.")
+        djsciops_utils.log("User successfully authenticated.", gui=gui)
         # generate user info
         connection = http.client.HTTPSConnection(lookup_service_domain)
         headers = {
@@ -166,6 +168,13 @@ def _delayed_request(*, url: str, delay: str = 0):
     return urllib.request.urlopen(url)
 
 
+def _decode_bearer_token(bearer_token):
+    jwt_data = json.loads(
+        base64.b64decode(bearer_token.split(".")[1].encode()).decode()
+    )
+    return jwt_data
+
+
 class Session:
     def __init__(
         self,
@@ -173,21 +182,24 @@ class Session:
         s3_role: str,
         auth_client_id: str,
         bearer_token: str = None,
+        gui=None,
     ):
-        djsciops_utils.log("authentication", message_type="header")
+        djsciops_utils.log("authentication", message_type="header", gui=gui)
         # OAuth2.0 authorization
         if not bearer_token:
-            self.bearer_token, self.user = _oidc_login(auth_client_id=auth_client_id)
-        else:
-            jwt_data = json.loads(
-                base64.b64decode(bearer_token.split(".")[1].encode()).decode()
+            self.bearer_token, self.user = _oidc_login(
+                auth_client_id=auth_client_id, gui=gui
             )
-            time_to_live = (jwt_data["exp"] - datetime.utcnow().timestamp()) / 60 / 60
+            self.jwt = _decode_bearer_token(self.bearer_token)
+        else:
+            self.jwt = _decode_bearer_token(self.bearer_token)
+            time_to_live = (self.jwt["exp"] - datetime.utcnow().timestamp()) / 60 / 60
             djsciops_utils.log(
                 f"Reusing provided bearer token with a life of {time_to_live} [HR]",
                 pause_duration=1,
+                gui=gui,
             )
-            self.bearer_token, self.user = (bearer_token, jwt_data["sub"])
+            self.bearer_token, self.user = (bearer_token, self.jwt["sub"])
         # AWS temporary credentials
         sts_client = boto3.client(service_name="sts")
         sts_response = sts_client.assume_role_with_web_identity(
