@@ -8,14 +8,14 @@ import collections.abc
 
 
 def _generate_transfer_mapping(
-    session, s3_bucket: str, source: Union[str, list], destination: Union[str, list]
+    session, s3_bucket: str, source: Union[str, list], destination: Union[str, list], gui=None
 ) -> tuple:
     if (
         isinstance(source, list)
         and isinstance(destination, list)
         and len(source) == len(destination)
     ):
-        djsciops_utils.log(f"Upload mapping provided.")
+        djsciops_utils.log(f"Upload mapping provided.", gui=gui)
         # expect file_paths to be list of Path, object_paths to be list of PurePosixPath
         file_paths, object_paths = (source, destination)
         existing_objects = {
@@ -101,13 +101,13 @@ def list_files(
 
 
 def upload_files(
-    session, s3_bucket: str, source: Union[str, list], destination: Union[str, list]
+    session, s3_bucket: str, source: Union[str, list], destination: Union[str, list], gui=None
 ):
-    djsciops_utils.log("axon copy", message_type="header")
+    djsciops_utils.log("axon copy", message_type="header", gui=gui)
     file_paths, object_paths = _generate_transfer_mapping(
-        session=session, s3_bucket=s3_bucket, source=source, destination=destination
+        session=session, s3_bucket=s3_bucket, source=source, destination=destination, gui=gui
     )
-    djsciops_utils.log("Starting upload\n")
+    djsciops_utils.log("Starting upload\n", gui=gui)
     with tqdm.tqdm(
         total=sum(os.stat(fp).st_size for fp in file_paths),
         unit="B",
