@@ -1,9 +1,9 @@
 import argparse
-from . import __version__ as version
-from . import authentication as djsciops_authentication
-from . import axon as djsciops_axon
-from . import settings as djsciops_settings
 import sys
+from djsciops import __version__ as version
+from djsciops import authentication as djsciops_authentication
+from djsciops import axon as djsciops_axon
+from djsciops import settings as djsciops_settings
 
 
 def djsciops(args: list = None):
@@ -51,3 +51,7 @@ def djsciops(args: list = None):
             destination=kwargs["destination"],
         )
     raise SystemExit
+
+
+if __name__ == "__main__":
+    djsciops()
