@@ -17,7 +17,7 @@ djauth:
 """
 
 
-def get_config():
+def get_config(stdin_enabled=True):
     djsciops_utils.log("configuration", message_type="header")
     config_directory = appdirs.user_data_dir(appauthor="datajoint", appname="djsciops")
     try:
@@ -30,7 +30,9 @@ def get_config():
             pause_duration=1,
         )
         return config
-    except FileNotFoundError:
+    except FileNotFoundError as e:
+        if not stdin_enabled:
+            raise e
         djsciops_utils.log(
             "Welcome! We've detected that this is your first time using DataJoint SciOps CLI tools. We'll need to ask a few questions to initialize properly.",
             pause_duration=5,
