@@ -5,13 +5,20 @@ import io
 from pathlib import Path
 
 
-def log(message: str, pause_duration: int = 0, message_type: str = "message"):
+def log(message: str, pause_duration: int = 0, message_type: str = "message", gui=None):
     if message_type == "message":
         print(f"\n -> {message}", flush=True)
+        if gui:
+            gui.upload_status.append(f"-> {message}")
     elif message_type == "header":
         print(f"\n=== {message.upper()} ===", flush=True)
+        if gui:
+            gui.upload_status.append(f"=== {message.upper()} ===")
     if pause_duration:
         time.sleep(pause_duration)
+    if gui:
+        gui.upload_status.verticalScrollBar().setValue(gui.upload_status.verticalScrollBar().maximum())
+        gui.upload_status.ensureCursorVisible()
 
 
 def uuid_from_stream(stream, *, init_string=""):
